Learn R Programming

datacheck (version 1.0.0)

is.onlyLowers: Tests if a string has only lower case letters

Description

Tests if a string has only lower case letters

Usage

is.onlyLowers(s)

Arguments

s
a character string

Value

  • boolean TRUE if detects anything

See Also

Other rule_checks: has.punct, is.oneOf, is.properName, is.withinRange

Examples

Run this code
is.onlyLowers("example") == TRUE

is.onlyLowers("Example") == FALSE

Run the code above in your browser using DataLab